@@ -31,31 +31,40 @@ import songwrite3.__editobj3__
 import songwrite3.midi
 
 editor_qt.MENU_LABEL_2_IMAGE.update({
-  "Add..."                             : "list-add",
-  "Remove"                             : "list-remove",
-  "Move up"                            : "go-up",
-  "Move down"                          : "go-down",
-  "Play from the beginning"            : "media-playback-start",
-  "Play from the beginning in loop"    : "media-playback-start",
-  "Play from here"                     : "media-playback-start",
-  "Play from here in loop"             : "media-playback-start",
-  "Stop playing"                       : "media-playback-stop",
-  "Edit..."                            : "document-properties",
-  "Songbook properties..."             : "document-properties",
-  "Song and instruments properties..." : "document-properties",
-  "Instrument properties..."           : "document-properties",
-  "Note properties..."                 : "document-properties",
-  "Save songbook as..."                : "document-save-as",
-  "preview_print"                      : "document-print",
-  "preview_print_songbook"             : "document-print",
-  "New window..."                      : "window-new",
-  "New song"                           : "document-new",
-  "New songbook"                       : "document-new",
-  "Select all"                         : "edit-select-all",
-  "Paste last selection"               : "edit-paste",
-  "About..."                           : "help-about",
-  "Manual..."                          : "help-contents",
-})
+  "Open..."                            : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-open.svg")),
+  "Save"                               : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-save.svg")),
+  "Save as..."                         : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-save.svg")),
+  "Close"                              : qtgui.QIcon(os.path.join(globdef.DATADIR, "window-close.svg")),
+  "Undo"                               : qtgui.QIcon(os.path.join(globdef.DATADIR, "edit-undo.svg")),
+  "Redo"                               : qtgui.QIcon(os.path.join(globdef.DATADIR, "edit-redo.svg")),
+  "Paste"                              : qtgui.QIcon(os.path.join(globdef.DATADIR, "edit-paste.svg")),
+  "Preferences..."                     : qtgui.QIcon(os.path.join(globdef.DATADIR, "preferences-desktop.svg")),
+  
+  "Add..."                             : qtgui.QIcon(os.path.join(globdef.DATADIR, "list-add.svg")),
+  "Remove"                             : qtgui.QIcon(os.path.join(globdef.DATADIR, "list-remove.svg")),
+  "Move up"                            : qtgui.QIcon(os.path.join(globdef.DATADIR, "go-up.svg")),
+  "Move down"                          : qtgui.QIcon(os.path.join(globdef.DATADIR, "go-down.svg")),
+  "Play from the beginning"            : qtgui.QIcon(os.path.join(globdef.DATADIR, "media-playback-start.svg")),
+  "Play from the beginning in loop"    : qtgui.QIcon(os.path.join(globdef.DATADIR, "media-playback-start.svg")),
+  "Play from here"                     : qtgui.QIcon(os.path.join(globdef.DATADIR, "media-playback-start.svg")),
+  "Play from here in loop"             : qtgui.QIcon(os.path.join(globdef.DATADIR, "media-playback-start.svg")),
+  "Stop playing"                       : qtgui.QIcon(os.path.join(globdef.DATADIR, "media-playback-stop.svg")),
+  "Edit..."                            : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-properties.svg")),
+  "Songbook properties..."             : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-properties.svg")),
+  "Song and instruments properties..." : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-properties.svg")),
+  "Instrument properties..."           : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-properties.svg")),
+  "Note properties..."                 : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-properties.svg")),
+  "Save songbook as..."                : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-save.svg")),
+  "preview_print"                      : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-print.svg")),
+  "preview_print_songbook"             : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-print.svg")),
+  "New window..."                      : qtgui.QIcon(os.path.join(globdef.DATADIR, "window-new.svg")),
+  "New song"                           : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-new.svg")),
+  "New songbook"                       : qtgui.QIcon(os.path.join(globdef.DATADIR, "document-new.svg")),
+  "Select all"                         : qtgui.QIcon(os.path.join(globdef.DATADIR, "edit-select-all.svg")),
+  "Paste last selection"               : qtgui.QIcon(os.path.join(globdef.DATADIR, "edit-paste.svg")),
+  "About..."                           : qtgui.QIcon(os.path.join(globdef.DATADIR, "help-about.svg")),
+  "Manual..."                          : qtgui.QIcon(os.path.join(globdef.DATADIR, "help-contents.svg")),
+  })
 
 from songwrite3.canvas import Canvas
 
@@ -63,6 +72,18 @@ app      = qtwidgets.QApplication(sys.argv)
 mainloop = app.exec
 app.setWindowIcon(qtgui.QIcon(os.path.join(globdef.DATADIR, "songwrite3_64x64.png")))
 
+
+
+# try:
+#   s = open(os.path.expanduser("~/.config/qt5ct/qt5ct.conf")).read()
+#   s = s.split("style=", 1)[1].split("\n", 1)[0]
+#   app.setStyle(s)
+#   del s
+# except: pass
+
+#if hasattr(qtcore.Qt, 'AA_EnableHighDpiScaling'): app.setAttribute(qtcore.Qt.AA_EnableHighDpiScaling, True)
+#if hasattr(qtcore.Qt, 'AA_UseHighDpiPixmaps'):    app.setAttribute(qtcore.Qt.AA_UseHighDpiPixmaps   , True)
+    
 def remove_accents(s): return unicodedata.normalize("NFKD", s).encode("ascii", "ignore").decode("ascii")
 
 
