@@ -26,6 +26,7 @@ import songwrite3.model     as model
 import songwrite3.globdef   as globdef
 import songwrite3.canvas    as canvas
 from songwrite3.plugins.chord.chord import ChordManager, TablatureChordManager, LyreChordManager, PianoChordManager, AccordionChordManager
+from songwrite3.canvas import ctx_drawText, ctx_drawText2, ctx_drawLine, ctx_drawRect, ctx_drawEllipse, ctx_drawPixmap
 
 def set_chord(canvas, partition, chord_manager, times, base, second = 0, third = 1, fourth = 0, fifth = 7, sixth = 0, seventh = 0):
   if third == 1: third = chord_manager.choose_third(partition, base)
@@ -295,7 +296,7 @@ class ChordDrawer(canvas.PartitionDrawer):
     ctx.setPen(self.note_color(notes[0]))
     rel_values = frozenset([note.value for note in notes])
     if rel_values == frozenset([0]):
-      ctx.drawText(self.canvas.time_2_x(notes[0].time) + self.note_offset_x, self.y + self.start_y + 2 * self.stem_extra_height, "_")
+      ctx_drawText(ctx, self.canvas.time_2_x(notes[0].time) + self.note_offset_x, self.y + self.start_y + 2 * self.stem_extra_height, "_")
     else:
       chord = self.chord_manager.identify(rel_values)
       if chord: name = chord.name
@@ -310,11 +311,11 @@ class ChordDrawer(canvas.PartitionDrawer):
             chord = self.chord_manager.identify(rel_values)
             if chord and ((not self.avoid_repeat) or (chord.name != name)):
               max_width = (self.canvas.time_2_x(next.time) - self.canvas.time_2_x(notes[0].time)) - 3 * self.scale
-        ctx.drawText(
+        ctx_drawText2(ctx, 
           self.canvas.time_2_x(notes[0].time) + self.note_offset_x,
           self.y + self.start_y + 2 * self.stem_extra_height - self.canvas.default_ascent,
           max_width,
-          999.0,
+          999,
           0,
           name,
         )
@@ -383,10 +384,10 @@ class AccordionChordDrawer(ChordDrawer):
       #ctx.move_to(85.0 * self.scale - text_width, self.y + 14.5 * self.scale)
       #ctx.show_text(_("LG"))
       if self.compact:
-        ctx.drawText(65.0 * self.scale, self.y + 20.0 * self.scale, _("LG"))
+        ctx_drawText(ctx, 65.0 * self.scale, self.y + 20.0 * self.scale, _("LG"))
         return canvas.PartitionDrawer.draw(self, ctx, x, y, width, height, drag, 0, -10.0)
       else:
-        ctx.drawText(65.0 * self.scale, self.y + 20.0 * self.scale, _("LG"))
+        ctx_drawText(ctx, 65.0 * self.scale, self.y + 20.0 * self.scale, _("LG"))
         return canvas.PartitionDrawer.draw(self, ctx, x, y, width, height, drag, 0, -20.0)
       
   def draw_stem_and_beam_for_chord(self, ctx, notes, notes_y, previous, next, appo = 0):
