@@ -189,7 +189,7 @@ class PartitionHandler(handler.ContentHandler):
                         )
       for attr in attrs.keys():
         setter = self.note_setter.get(attr, 1)
-        if   setter is 1:
+        if   setter == 1:
           value = attrs[attr]
           try: value = int(value)
           except:
